aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-smb.h
diff options
context:
space:
mode:
authorRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2007-05-10 20:53:35 +0000
committerRonnie Sahlberg <ronnie_sahlberg@ozemail.com.au>2007-05-10 20:53:35 +0000
commitf43afbaf356eb2c55d54ae1c3d23d979978c9269 (patch)
treedacb9ac626025225c92c856cd239768f9520a650 /epan/dissectors/packet-smb.h
parent6c310715bdac36a643ef2f93c81f7f0793b1ca54 (diff)
add more tracking of FID properties
track create_flags, access_mask, file_attributes, share_access and create options for all FIDs svn path=/trunk/; revision=21743
Diffstat (limited to 'epan/dissectors/packet-smb.h')
-rw-r--r--epan/dissectors/packet-smb.h22
1 files changed, 20 insertions, 2 deletions
diff --git a/epan/dissectors/packet-smb.h b/epan/dissectors/packet-smb.h
index 3fb6ff56fb..02227d6598 100644
--- a/epan/dissectors/packet-smb.h
+++ b/epan/dissectors/packet-smb.h
@@ -204,7 +204,8 @@ typedef enum {
SMB_EI_NTI, /* smb_nt_transact_info_t * */
SMB_EI_TRI, /* smb_transact_info_t * */
SMB_EI_T2I, /* smb_transact2_info_t * */
- SMB_EI_FILENAME, /* fid tracking char * */
+ SMB_EI_TIDNAME, /* tid tracking char * */
+ SMB_EI_FILEDATA, /* fid tracking */
SMB_EI_UID /* smb_uid_t */
} smb_extra_info_t;
typedef struct {
@@ -290,14 +291,31 @@ extern int dissect_file_data(tvbuff_t *tvb, proto_tree *tree, int offset,
#define SMB_FID_TYPE_FILE 1
#define SMB_FID_TYPE_DIR 2
#define SMB_FID_TYPE_PIPE 3
+
/* used for tracking fid/tid to filename/sharename openedframe closedframe */
+typedef struct _smb_fid_saved_info_t {
+ char *filename;
+ guint32 create_flags;
+ guint32 access_mask;
+ guint32 file_attributes;
+ guint32 share_access;
+ guint32 create_options;
+} smb_fid_saved_info_t;
typedef struct _smb_fid_into_t {
int opened_in;
int closed_in;
- char *filename;
int type;
+ smb_fid_saved_info_t *fsi;
} smb_fid_info_t;
+/* used for tracking tid to sharename openedframe closedframe */
+typedef struct _smb_tid_into_t {
+ int opened_in;
+ int closed_in;
+ char *filename;
+ int type;
+} smb_tid_info_t;
+
/*
* Dissect an smb FID